Crate bhc_data_structures

Crate bhc_data_structures 

Common data structures for the BHC compiler.

This crate re-exports and provides wrappers around commonly used data structures, ensuring consistent hashing and performance.

Structs

FrozenMap
A frozen hash map that becomes immutable after construction.
IndexMap
A hash table where the iteration order of the key-value pairs is independent of the hash values of the keys.
IndexSet
A hash set where the iteration order of the values is independent of their hash values.
SmallVec
A Vec-like container that can store a small number of elements inline.
UnionFind
A union-find (disjoint set) data structure.
WorkQueue
A work queue for graph traversals.

Traits

FxHashMapExt
Extension trait for creating FxHashMap instances.
FxHashSetExt
Extension trait for creating FxHashSet instances.

Type Aliases

FxHashMap
A hash map using FxHasher for fast hashing.
FxHashSet
A hash set using FxHasher for fast hashing.
FxIndexMap
An insertion-ordered hash map.
FxIndexSet
An insertion-ordered hash set.
Mutex
A mutual exclusion primitive useful for protecting shared data
RwLock
A reader-writer lock
SmallVec8
A small vector optimized for holding 0-8 elements inline.
TinyVec
A small vector optimized for holding 0-4 elements inline.