Common data structures for the BHC compiler.
This crate re-exports and provides wrappers around commonly used data structures, ensuring consistent hashing and performance.
Structs
- Frozen
Map - A frozen hash map that becomes immutable after construction.
- Index
Map - A hash table where the iteration order of the key-value pairs is independent of the hash values of the keys.
- Index
Set - A hash set where the iteration order of the values is independent of their hash values.
- Small
Vec - A
Vec-like container that can store a small number of elements inline. - Union
Find - A union-find (disjoint set) data structure.
- Work
Queue - A work queue for graph traversals.
Traits
- FxHash
MapExt - Extension trait for creating
FxHashMapinstances. - FxHash
SetExt - Extension trait for creating
FxHashSetinstances.
Type Aliases
- FxHash
Map - A hash map using
FxHasherfor fast hashing. - FxHash
Set - A hash set using
FxHasherfor fast hashing. - FxIndex
Map - An insertion-ordered hash map.
- FxIndex
Set - An insertion-ordered hash set.
- Mutex
- A mutual exclusion primitive useful for protecting shared data
- RwLock
- A reader-writer lock
- Small
Vec8 - A small vector optimized for holding 0-8 elements inline.
- TinyVec
- A small vector optimized for holding 0-4 elements inline.